import {
  select,
  json,
  geoMercator,
  geoPath,
  schemeCategory10,
  scaleOrdinal,
} from 'd3';
import { feature } from 'topojson';

// Select the SVG element
const svg = select('svg');

// Set the width and height of the SVG
const width = window.innerWidth;
const height = window.innerHeight;

// Set the heading of the map
const HeaderText = 'USA Map';
svg
  .append('text')
  .attr('y', 50)
  .attr('x', 150)
  .text(HeaderText)
  .attr('class', 'Header');

// Define the projection for the USA map
const projection = geoMercator()
  .translate([width / 2, height / 2])
  .scale(1000);

// Define the path generator
const pathGen = geoPath(projection);

// Define the color scale
const colorScale = scaleOrdinal(schemeCategory10);

// Load the USA map data
json('https://d3js.org/us-10m.v1.json').then((data) => {
  // Parse the data
  const usa = feature(data, data.objects.states);

  // Create the map
  svg
    .selectAll('path')
    .data(usa.features)
    .enter()
    .append('path')
    .attr('class', 'state')
    .attr('fill', (d, i) => colorScale(i))
    .attr('d', pathGen)
    .append('title')
    .text((d) => d.properties.name);
});
